/*
 * Copyright 2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Header:$
 */
package org.apache.beehive.netui.pageflow;

import org.apache.struts.action.ActionForm;

import java.util.Map;
import java.util.Set;
import java.util.Collections;
import java.util.Collection;


/**
 * ActionForm/Map that stores no properties and emits no errors.
 */
class NullActionForm extends ActionForm implements Map
{
    public int size()
    {
        return 0;
    }

    public boolean isEmpty()
    {
        return true;
    }

    public boolean containsKey( Object key )
    {
        return false;
    }

    public boolean containsValue( Object value )
    {
        return false;
    }

    public Object get( Object key )
    {
        //
        // We return a reference to the current bean, so that when BeanUtils tries to resolve properties
        // (e.g., "foo.bar.baz"), we get an unlimited chain of Maps that won't cause it to throw errors.
        //
        return this;
    }

    public Object put( Object o, Object o1 )
    {
        return null;
    }

    public Object remove( Object key )
    {
        return null;
    }

    public void putAll( Map map )
    {
    }

    public void clear()
    {
    }

    public Set keySet()
    {
        return Collections.emptySet();
    }

    public Collection values()
    {
        return Collections.emptyList();
    }

    public Set entrySet()
    {
        return Collections.emptySet();
    }
}


